@@ -47,6 +47,7 @@
 #include "addressbook/gui/widgets/eab-menu.h"
 
 #include "e-util/e-categories-master-list-wombat.h"
+#include "e-util/e-print.h"
 #include "libedataserver/e-sexp.h"
 
 #ifdef WITH_ADDRESSBOOK_VIEW_TREEVIEW
@@ -98,7 +99,7 @@ static void stop_state_changed (GtkObject *object, EABView *eav);
 static void writable_status    (GtkObject *object, gboolean writable, EABView *eav);
 static void backend_died       (GtkObject *object, EABView *eav);
 static void contact_changed    (EABModel *model, gint index, EABView *eav);
-static void contact_removed    (EABModel *model, gint index, EABView *eav);
+static void contacts_removed    (EABModel *model, gpointer data, EABView *eav);
 static GList *get_selected_contacts (EABView *view);
 
 static void command_state_change (EABView *eav);
@@ -435,8 +436,8 @@ eab_view_new (void)
 			  G_CALLBACK (backend_died), eav);
 	g_signal_connect (eav->model, "contact_changed",
 			  G_CALLBACK (contact_changed), eav);
-	g_signal_connect (eav->model, "contact_removed",
-			  G_CALLBACK (contact_removed), eav);
+	g_signal_connect (eav->model, "contacts_removed",
+			  G_CALLBACK (contacts_removed), eav);
 
 	eav->editable = FALSE;
 	eav->query = g_strdup (SHOW_ALL_SEARCH);
@@ -928,7 +929,7 @@ static EPopupItem eabv_popup_items[] = {
 	{ E_POPUP_ITEM, "90.moveto", N_("Move to Address Book..."), move_to_folder, NULL, NULL, 0, EAB_POPUP_SELECT_ANY|EAB_POPUP_SELECT_EDITABLE },
 
 	{ E_POPUP_BAR, "a0.bar" },
-	{ E_POPUP_BAR, "b0.cut", N_("Cut"), cut, NULL, "stock_cut", 0, EAB_POPUP_SELECT_ANY|EAB_POPUP_SELECT_EDITABLE },
+	{ E_POPUP_ITEM, "b0.cut", N_("Cut"), cut, NULL, "stock_cut", 0, EAB_POPUP_SELECT_ANY|EAB_POPUP_SELECT_EDITABLE },
 	{ E_POPUP_ITEM, "c0.copy", N_("Copy"), copy, NULL, "stock_copy", 0, EAB_POPUP_SELECT_ANY },
 	{ E_POPUP_ITEM, "d0.paste", N_("Paste"), paste, NULL, "stock_paste", 0, EAB_POPUP_SELECT_EDITABLE },
 	{ E_POPUP_ITEM, "e0.delete", N_("Delete"), delete, NULL, "stock_delete", 0, EAB_POPUP_SELECT_EDITABLE|EAB_POPUP_SELECT_ANY },
@@ -1188,13 +1189,23 @@ contact_changed (EABModel *model, gint index, EABView *eav)
 }
 
 static void
-contact_removed (EABModel *model, gint index, EABView *eav)
+contacts_removed (EABModel *model, gpointer data, EABView *eav)
 {
-	if (eav->displayed_contact == index) {
-		/* if the contact that's presently displayed is changed, clear the display */
-		eab_contact_display_render (EAB_CONTACT_DISPLAY (eav->contact_display), NULL,
-					    EAB_CONTACT_DISPLAY_RENDER_NORMAL);
-		eav->displayed_contact = -1;
+	GArray *indices = (GArray *) data;
+	int count = indices->len;
+	gint i;
+
+	for (i = 0; i < count; i ++) {
+	
+		
+		if (eav->displayed_contact == g_array_index (indices, gint, i)) {
+			
+			/* if the contact that's presently displayed is changed, clear the display */
+			eab_contact_display_render (EAB_CONTACT_DISPLAY (eav->contact_display), NULL,
+						    EAB_CONTACT_DISPLAY_RENDER_NORMAL);
+			eav->displayed_contact = -1;
+			break;
+		}
 	}
 }
 
@@ -1479,7 +1490,7 @@ static void
 search_menu_activated (ESearchBar *esb, int id, EABView *view)
 {
 	if (id == ESB_ADVANCED)
-		gtk_widget_show(eab_search_dialog_new(view));
+		e_search_bar_set_item_id (esb, id);
 }
 
 static void
@@ -1728,7 +1739,7 @@ eab_view_print(EABView *view)
 			      NULL);
 		print = e_contact_print_dialog_new(book, query);
 		g_free(query);
-		gtk_widget_show_all(print);
+		gtk_widget_show(print);
 	}
 	else if (view->view_type == EAB_VIEW_TABLE) {
 		GtkWidget *dialog;
@@ -1736,7 +1747,7 @@ eab_view_print(EABView *view)
 		ETable *etable;
 		EContactPrintDialogWeakData *weak_data;
 
-		dialog = gnome_print_dialog_new(NULL, "Print cards", GNOME_PRINT_DIALOG_RANGE | GNOME_PRINT_DIALOG_COPIES);
+		dialog = e_print_get_dialog (_("Print cards"), GNOME_PRINT_DIALOG_RANGE | GNOME_PRINT_DIALOG_COPIES);
 		gnome_print_dialog_construct_range_any(GNOME_PRINT_DIALOG(dialog), GNOME_PRINT_RANGE_ALL | GNOME_PRINT_RANGE_SELECTION,
 						       NULL, NULL, NULL);
 
@@ -1796,9 +1807,8 @@ eab_view_print_preview(EABView *view)
 		g_object_ref (printable);
 		gtk_object_sink (GTK_OBJECT (printable));
 
-		master = gnome_print_job_new(NULL);
-		config = gnome_print_job_get_config (master);
-		gnome_print_config_set_int (config, GNOME_PRINT_KEY_NUM_COPIES, 1);
+		config = e_print_load_config ();
+		master = gnome_print_job_new (config);
 		pc = gnome_print_job_get_context( master );
 		e_printable_reset(printable);
 		while (e_printable_data_left(printable)) {
