@@ -682,6 +682,13 @@ e_minicard_event (GnomeCanvasItem *item, GdkEvent *event)
 						view_index--;
 
 					model_index = e_sorter_sorted_to_model (E_SORTER (reflow->sorter), view_index);
+					if (reflow->items[model_index] == NULL) {
+						reflow->items[model_index] = e_reflow_model_incarnate (reflow->model, model_index, GNOME_CANVAS_GROUP (reflow));
+						g_object_set (reflow->items[model_index],
+							      "width", (double) reflow->column_width,
+							      NULL);
+
+					}
 					e_canvas_item_grab_focus (reflow->items[model_index], FALSE);
 					return TRUE;
 				}
@@ -701,6 +708,13 @@ e_minicard_event (GnomeCanvasItem *item, GdkEvent *event)
 						view_index++;
 
 					model_index = e_sorter_sorted_to_model (E_SORTER (reflow->sorter), view_index);
+					if (reflow->items[model_index] == NULL) {
+						reflow->items[model_index] = e_reflow_model_incarnate (reflow->model, model_index, GNOME_CANVAS_GROUP (reflow));
+						g_object_set (reflow->items[model_index],
+							      "width", (double) reflow->column_width,
+							      NULL);
+
+					}
 					e_canvas_item_grab_focus(reflow->items[model_index], FALSE);
 					return TRUE;
 				}
@@ -840,7 +854,7 @@ remodel( EMinicard *e_minicard )
 		list = e_minicard->fields;
 		e_minicard->fields = NULL;
 
-		for(field = E_CONTACT_FULL_NAME; field != E_CONTACT_LAST_SIMPLE_STRING && count < 5; field++) {
+		for(field = E_CONTACT_FULL_NAME; field != (E_CONTACT_LAST_SIMPLE_STRING -1) && count < 5; field++) {
 			EMinicardField *minicard_field = NULL;
 
 			if (field == E_CONTACT_FAMILY_NAME || field == E_CONTACT_GIVEN_NAME)
