@@ -526,13 +526,13 @@ emae_auto_detect(EMAccountEditor *emae)
 	    || (entries = service->provider->extra_conf) == NULL)
 		return;
 
-	printf("Running auto-detect\n");
+	d(printf("Running auto-detect\n"));
 
 	url = emae_account_url(emae, E_ACCOUNT_SOURCE_URL);
 	camel_provider_auto_detect(service->provider, url, &auto_detected, NULL);
 	camel_url_free(url);
 	if (auto_detected == NULL) {
-		printf(" no values detected\n");
+		d(printf(" no values detected\n"));
 		return;
 	}
 
@@ -647,8 +647,6 @@ emae_signaturetype_changed(GtkComboBox *dropdown, EMAccountEditor *emae)
 			gtk_tree_model_get(model, &iter, 1, &uid, -1);
 	}
 
-	printf("signaturetype changed: %d uid=%s\n", id, uid?uid:"");
-
 	e_account_set_string(emae->account, E_ACCOUNT_ID_SIGNATURE, uid);
 	g_free(uid);
 }
@@ -699,7 +697,6 @@ emae_setup_signatures(EMAccountEditor *emae, GladeXML *xml)
 		gtk_list_store_append(store, &iter);
 		gtk_list_store_set(store, &iter, 0, sig->autogen?_("Autogenerated"):sig->name, 1, sig->uid, -1);
 
-		printf("check sig '%s' is ours '%s' = %s\n", sig->uid, current, (current && !strcmp(current, sig->uid))?"yep":"no");
 		if (current && !strcmp(current, sig->uid))
 			active = i;
 
@@ -726,6 +723,64 @@ emae_setup_signatures(EMAccountEditor *emae, GladeXML *xml)
 	return (GtkWidget *)dropdown;
 }
 
+static void
+emae_receipt_policy_changed(GtkComboBox *dropdown, EMAccountEditor *emae)
+{
+	int id = gtk_combo_box_get_active(dropdown);
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	EAccountReceiptPolicy policy;
+
+	if (id != -1) {
+		model = gtk_combo_box_get_model(dropdown);
+		if (gtk_tree_model_iter_nth_child(model, &iter, NULL, id)) {
+			gtk_tree_model_get(model, &iter, 1, &policy, -1);
+			e_account_set_int (emae->account, E_ACCOUNT_RECEIPT_POLICY, policy);
+		}
+	}
+
+}
+
+static GtkWidget *
+emae_setup_receipt_policy (EMAccountEditor *emae, GladeXML *xml)
+{
+	GtkComboBox *dropdown = (GtkComboBox *)glade_xml_get_widget(xml, "receipt_policy_dropdown");
+	GtkListStore *store;
+	int i = 0, active = 0;
+	GtkTreeIter iter;
+	EAccountReceiptPolicy current = emae->account->receipt_policy;
+	static struct {
+		EAccountReceiptPolicy policy;
+		char *label;			
+	} receipt_policies[] = {
+		{ E_ACCOUNT_RECEIPT_NEVER,  N_("Never") },
+		{ E_ACCOUNT_RECEIPT_ALWAYS, N_("Always") },
+		{ E_ACCOUNT_RECEIPT_ASK,    N_("Ask for each message") }
+	};
+
+	gtk_widget_show((GtkWidget *)dropdown);
+
+	store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
+
+	for (i = 0; i < 3; ++i) {
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter,
+				    0, _(receipt_policies[i].label),
+				    1, receipt_policies[i].policy,
+				    -1);
+		if (current == receipt_policies[i].policy)
+			active = i;		
+	}
+	
+	gtk_combo_box_set_model(dropdown, (GtkTreeModel *)store);
+	gtk_combo_box_set_active(dropdown, active);
+
+	g_signal_connect(dropdown, "changed", G_CALLBACK(emae_receipt_policy_changed), emae);
+	gtk_widget_set_sensitive((GtkWidget *)dropdown, e_account_writable(emae->account, E_ACCOUNT_RECEIPT_POLICY));
+
+	return (GtkWidget *)dropdown;
+}
+
 static void
 emae_account_entry_changed(GtkEntry *entry, EMAccountEditor *emae)
 {
@@ -1919,7 +1974,7 @@ emae_receive_options_extra_item(EConfig *ec, EConfigItem *eitem, struct _GtkWidg
 
 	return NULL;
 section:
-	printf("Building extra section '%s'\n", eitem->path);
+	d(printf("Building extra section '%s'\n", eitem->path));
 
 	url = emae_account_url(emae, emae_service_info[service->type].account_uri_key);
 	item->extra_table = g_hash_table_new(g_str_hash, g_str_equal);
@@ -2084,6 +2139,9 @@ emae_defaults_page(EConfig *ec, EConfigItem *item, struct _GtkWidget *parent, st
 	gtk_widget_set_sensitive((GtkWidget *)gui->restore_folders_button,
 				 e_account_writable(emae->account, E_ACCOUNT_SENT_FOLDER_URI)
 				 || e_account_writable(emae->account, E_ACCOUNT_DRAFTS_FOLDER_URI));
+
+	/* Receipt policy */
+	emae_setup_receipt_policy (emae, xml);
 	
 	w = glade_xml_get_widget(xml, item->label);
 	gtk_notebook_append_page((GtkNotebook *)parent, w, gtk_label_new(_("Defaults")));
@@ -2226,7 +2284,6 @@ emae_management_page(EConfig *ec, EConfigItem *item, struct _GtkWidget *parent,
 static GtkWidget *
 emae_widget_druid_glade(EConfig *ec, EConfigItem *item, struct _GtkWidget *parent, struct _GtkWidget *old, void *data)
 {
-	EMAccountEditor *emae = data;
 	GladeXML *druidxml = glade_xml_new(EVOLUTION_GLADEDIR "/mail-config.glade", item->label, NULL);
 	GtkWidget *w;
 
@@ -2352,19 +2409,19 @@ emae_check_complete(EConfig *ec, const char *pageid, void *data)
 			    || tmp[0] == 0
 			    || is_email(tmp));
 		if (!ok)
-			printf("identity incomplete\n");
+			d(printf("identity incomplete\n"));
 	}
 
 	if (ok && (pageid == NULL || !strcmp(pageid, "10.receive"))) {
 		ok = emae_service_complete(emae, &emae->priv->source);
 		if (!ok)
-			printf("receive page incomplete\n");
+			d(printf("receive page incomplete\n"));
 	}
 
 	if (ok && (pageid == NULL || !strcmp(pageid, "30.send"))) {
 		ok = emae_service_complete(emae, &emae->priv->transport);
 		if (!ok)
-			printf("send page incomplete\n");
+			d(printf("send page incomplete\n"));
 	}
 
 	if (ok && (pageid == NULL || !strcmp(pageid, "40.management"))) {
@@ -2373,7 +2430,7 @@ emae_check_complete(EConfig *ec, const char *pageid, void *data)
 			&& ((ea = mail_config_get_account_by_name(tmp)) == NULL
 			    || ea == emae->original);
 		if (!ok)
-			printf("management page incomplete\n");
+			d(printf("management page incomplete\n"));
 	}
 
 	/* We use the page-check of various pages to 'prepare' or
@@ -2454,12 +2511,12 @@ emae_commit(EConfig *ec, GSList *items, void *data)
 	/* the mail-config*acconts* api needs a lot of work */
 
 	if (emae->original) {
-		printf("Committing account '%s'\n", e_account_get_string(emae->account, E_ACCOUNT_NAME));
+		d(printf("Committing account '%s'\n", e_account_get_string(emae->account, E_ACCOUNT_NAME)));
 		e_account_import(emae->original, emae->account);
 		account = emae->original;
 		e_account_list_change(accounts, account);
 	} else {
-		printf("Adding new account '%s'\n", e_account_get_string(emae->account, E_ACCOUNT_NAME));
+		d(printf("Adding new account '%s'\n", e_account_get_string(emae->account, E_ACCOUNT_NAME)));
 		e_account_list_add(accounts, emae->account);
 		account = emae->account;
 
