@@ -34,7 +34,7 @@
 #include <camel/camel-mime-message.h>
 #include <camel/camel-url.h>
 
-#include <gal/util/e-iconv.h>
+#include <libedataserver/e-iconv.h>
 #include <libgnome/gnome-i18n.h>
 
 #include "em-stripsig-filter.h"
@@ -354,6 +354,8 @@ emfq_format_headers (EMFormatQuote *emfq, CamelStream *stream, CamelMedium *part
 		emfq_format_header (emf, stream, part, h->name, h->flags, charset);
 		h = h->next;
 	}
+
+	camel_stream_printf(stream, "<br>\n");
 }
 
 static void
