@@ -1011,7 +1011,7 @@ extract_itip_data (FormatItipPObject *pitip, GtkContainer *container)
 		return FALSE;	       
 	}
 
-	switch (kind) {
+	switch (icalcomponent_isa (pitip->ical_comp)) {
 	case ICAL_VEVENT_COMPONENT:
 		pitip->type = E_CAL_SOURCE_TYPE_EVENT;
 		break;
@@ -1732,6 +1732,7 @@ itip_formatter_page_factory (EPlugin *ep, EConfigHookItemFactoryData *hook_data)
 	gtk_box_pack_start (GTK_BOX (inner_vbox), scrolledwin, TRUE, TRUE, 0);
 
 	ess = e_source_selector_new (source_list);
+	atk_object_set_name (gtk_widget_get_accessible (ess), _("Conflict Search Table"));
 	gtk_container_add (GTK_CONTAINER (scrolledwin), ess);
 
 	initialize_selection (E_SOURCE_SELECTOR (ess), source_list);
