@@ -139,7 +139,7 @@ format_date_and_time_x		(struct tm	*date_tm,
 	
 	/* Calculate a normalized "tomorrow" */
 	tomorrow_tm = *current_tm;
-	if (tomorrow_tm.tm_mday == time_days_in_month (date_tm->tm_year + 1900, date_tm->tm_mon)) {
+	if (tomorrow_tm.tm_mday == time_days_in_month (date_tm->tm_year + 1900, date_tm->tm_mon - 1)) {
 		tomorrow_tm.tm_mday = 1;
 		if (tomorrow_tm.tm_mon == 11) {
 			tomorrow_tm.tm_mon = 1;
@@ -153,8 +153,8 @@ format_date_and_time_x		(struct tm	*date_tm,
 
 	/* Calculate a normalized "next seven days" */
 	week_tm = *current_tm;
-	if (week_tm.tm_mday + 6 > time_days_in_month (date_tm->tm_year + 1900, date_tm->tm_mon)) {
-		week_tm.tm_mday = (week_tm.tm_mday + 6) % time_days_in_month (date_tm->tm_year + 1900, date_tm->tm_mon);
+	if (week_tm.tm_mday + 6 > time_days_in_month (date_tm->tm_year + 1900, date_tm->tm_mon - 1)) {
+		week_tm.tm_mday = (week_tm.tm_mday + 6) % time_days_in_month (date_tm->tm_year + 1900, date_tm->tm_mon - 1);
 		if (week_tm.tm_mon == 11) {
 			week_tm.tm_mon = 1;
 			week_tm.tm_year++;
@@ -905,7 +905,7 @@ itip_view_init (ItipView *view)
 	priv->description_label = gtk_label_new (NULL);
 	gtk_label_set_line_wrap (GTK_LABEL (priv->description_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (priv->description_label), 0, 0.5);
-//	gtk_box_pack_start (GTK_BOX (vbox), priv->description_label, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), priv->description_label, FALSE, FALSE, 0);
 
 	separator = gtk_hseparator_new ();
 	gtk_widget_show (separator);
