@@ -40,12 +40,16 @@
 #include <camel/camel-store.h>
 #include <camel/camel-session.h>
 #include <camel/camel-store.h>
+#include <camel/camel-offline-store.h>
 #include <camel/camel-vee-store.h>
 #include <camel/camel-folder.h>
+#include <camel/camel-offline-store.h>
 #include <e-gw-container.h>
 #include <e-gw-connection.h>
 #include <glade/glade.h>
+#include <widgets/misc/e-error.h>
 #include <libgnomeui/libgnomeui.h>
+#include <widgets/misc/e-error.h>
 #include "share-folder.h"
 #define d(x)
 
@@ -164,7 +168,7 @@ create_folder__created (struct _mail_msg *mm)
 		if(E_IS_GW_CONNECTION (ccnc)) {
 			(ssi->sf)->cnc = ccnc;
 
-			(ssi->sf)->container_id = g_strdup (get_container_id ((ssi->sf)->cnc, m->name));
+			(ssi->sf)->container_id = get_container_id ((ssi->sf)->cnc, m->full_name);
 			share_folder(ssi->sf);
 		}
 
@@ -212,6 +216,19 @@ create_folder (CamelStore *store, const char *full_name, void (* done) (struct _
 	struct _EMCreateFolder *m;
 	const char *parent;
 	int id;
+	
+	
+	if (((CamelOfflineStore *) store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL) {
+		//e_error_run (NULL,  _("Cannot create GroupWise folders in offline mode."), NULL, NULL);
+		g_warning (_("Cannot Create shared folder in offline mode."));
+		return -1;
+	}
+	
+	if (((CamelOfflineStore *) store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL) {
+		//e_error_run (NULL,  _("Cannot create GroupWise folders in offline mode."), NULL, NULL);
+		g_warning (_("Cannot Create shared folder in offline mode."));
+		return -1;
+	}
 
 	namebuf = g_strdup (full_name);
 	if (!(name = strrchr (namebuf, '/'))) {
@@ -360,23 +377,26 @@ org_gnome_shared_folder_factory (EPlugin *ep, EConfigHookItemFactoryData *hook_d
 	gchar *account = NULL;
 	gchar *id = NULL;
 	gchar *sub = NULL;
+	gchar *folder_name = NULL;
 	EGwConnection *cnc;
 	ShareFolder *sharing_tab;
 	EMConfigTargetFolder *target=  (EMConfigTargetFolder *)hook_data->config->target;
-
-	folderuri = g_strdup(target->uri);
-	if (folderuri) {
-		account = g_strrstr(folderuri, "groupwise");
-		sub = g_strrstr(folderuri, "#");
-	} else
-		return NULL;
+	CamelFolder *folder = target->folder;
 	
-	if(sub == NULL)
-		sub = g_strrstr(folderuri, "/");
+	folder_name = g_strdup (folder->full_name);
+	folderuri = g_strdup(target->uri);
+	if (folderuri && folder_name) 
+		account = g_strrstr(folderuri, "groupwise");
+	else
+		return NULL;
+
+	sub =  g_strrstr (folder_name, "/");
 	if (sub)
 		sub++;
 	else
-		return NULL;
+		sub = folder_name;	
+
+	 /* This is kind of bad..but we don't have types for all these folders.*/
 
 	if ( !( strcmp (sub, "Mailbox") && strcmp (sub, "Calendar") && strcmp (sub, "Contacts") && strcmp (sub, "Documents") && strcmp (sub, "Authored") && strcmp (sub, "Default Library") && strcmp (sub, "Work In Progress") && strcmp (sub, "Cabinet") && strcmp (sub, "Sent Items") && strcmp (sub, "Trash") && strcmp (sub, "Checklist"))) {
 		g_free (folderuri);
@@ -384,23 +404,22 @@ org_gnome_shared_folder_factory (EPlugin *ep, EConfigHookItemFactoryData *hook_d
 	}
 
 	if (account) {
-		CamelFolder *folder = target->folder;
 		CamelStore *store = folder->parent_store;	
 		cnc = get_cnc (store);	
+	
 		if (E_IS_GW_CONNECTION (cnc)) 
-			id = get_container_id (cnc, sub);
+			id = get_container_id (cnc, folder_name);
 		else
 			g_warning("Could not Connnect\n");
 		
-		g_free (folderuri);
 		if (cnc && id)
 			sharing_tab = share_folder_new (cnc, id);
 		else 
 			return NULL;
-
+		
 		gtk_notebook_append_page((GtkNotebook *) hook_data->parent, (GtkWidget *) sharing_tab->vbox, gtk_label_new_with_mnemonic N_("Sharing"));
 		common = sharing_tab;
-
+		g_free (folderuri);
 		return GTK_WIDGET (sharing_tab);
 	} else
 		return NULL;
@@ -410,32 +429,43 @@ EGwConnection *
 get_cnc (CamelStore *store)
 {
 		EGwConnection *cnc;
-		const char *uri, *property_value, *use_ssl, *server_name, *user, *port;
+		const char *uri, *property_value, *server_name, *user, *port;
+		char *use_ssl;
 		CamelService *service;
 		CamelURL *url;
 		
 		if (!store)
 			return  NULL;
 
+		if (((CamelOfflineStore *) store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL)
+			return NULL;	
+
 		service = CAMEL_SERVICE(store);
 		url = service->url;
 		server_name = g_strdup (url->host);
 		user = g_strdup (url->user);
 		property_value =  camel_url_get_param (url, "soap_port");
-		use_ssl = g_strdup (camel_url_get_param (url, "soap_ssl"));
+		use_ssl = g_strdup (camel_url_get_param (url, "use_ssl"));
 		if(property_value == NULL)
-			port = g_strdup ("7181");
+			port = g_strdup ("7191");
 		else if (strlen(property_value) == 0)
-			port = g_strdup ("7181");
+			port = g_strdup ("7191");
 		else
 			port = g_strdup (property_value);
 
-		if (use_ssl)
+		if (use_ssl && !g_str_equal (use_ssl, "never"))
 			uri = g_strconcat ("https://", server_name, ":", port, "/soap", NULL);	
 		else
 			uri = g_strconcat ("http://", server_name, ":", port, "/soap", NULL);
 
 		cnc = e_gw_connection_new (uri, user, service->url->passwd);
+		if (!E_IS_GW_CONNECTION(cnc) && use_ssl && g_str_equal (use_ssl, "when-possible")) {
+			char *http_uri = g_strconcat ("http://", uri + 8, NULL);
+			cnc = e_gw_connection_new (http_uri, user, service->url->passwd);
+			g_free (http_uri);
+		}
+		g_free (use_ssl);
+		use_ssl = NULL;
 
 		return cnc;
 
@@ -446,23 +476,39 @@ get_container_id(EGwConnection *cnc, gchar *fname)
 {
 	GList *container_list = NULL;	
 	gchar *id = NULL;
-	const char *name;
+	gchar *name;
+	gchar **names;
+	int i = 0, parts = 0;
+
+	names = g_strsplit (fname, "/", -1);
+	if(names){
+		while (names [parts])
+			parts++;
+		fname = names[i]; 
+	}
+
 	/* get list of containers */
 	if (e_gw_connection_get_container_list (cnc, "folders", &(container_list)) == E_GW_CONNECTION_STATUS_OK) {
 		GList *container = NULL;
 
 		for (container = container_list; container != NULL; container = container->next) {
-			name = e_gw_container_get_name (container->data);
+			name = g_strdup (e_gw_container_get_name (container->data));
 			/* if Null is passed as name then we return top lavel id*/
 			if (fname == NULL) {
 				id = g_strdup (e_gw_container_get_id (container->data));
 				break;
 			} else if (!strcmp (name, fname)) {
-				id = g_strdup (e_gw_container_get_id (container->data));
-				break;
+				if (i == parts - 1) {
+					id = g_strdup (e_gw_container_get_id (container->data));
+					break;
+				} else
+					fname = names[++i];
 			}
+			g_free (name);
 		}
 		e_gw_connection_free_container_list (container_list);
+		if (names)
+		g_strfreev(names);
 	}
 	return id;
 }
